|
|
|
|
|
|
|
|
|
|
xen-devel
[Xen-devel] [PATCH] Add new location of Linux direct-map to the places t
Add new location of Linux direct-map to the places to look for
writable mappings.
Signed-off-by: George Dunlap <george.dunlap@xxxxxxxxxxxxx>
diff -r dbac9ee4d761 xen/arch/x86/mm/shadow/common.c
--- a/xen/arch/x86/mm/shadow/common.c Mon Sep 08 16:02:13 2008 +0100
+++ b/xen/arch/x86/mm/shadow/common.c Fri Sep 12 16:42:32 2008 +0100
@@ -2385,9 +2385,11 @@ int sh_remove_write_access(struct vcpu *
+ ((fault_addr & VADDR_MASK) >> 27), 3); break;
}
/* 64bit Linux direct map at 0xffff810000000000; older kernels
* had it at 0x0000010000000000UL */
gfn = mfn_to_gfn(v->domain, gmfn);
+ GUESS(0xffff880000000000UL + (gfn << PAGE_SHIFT), 4);
GUESS(0xffff810000000000UL + (gfn << PAGE_SHIFT), 4);
GUESS(0x0000010000000000UL + (gfn << PAGE_SHIFT), 4);
_______________________________________________
Xen-devel mailing list
Xen-devel@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-devel
|
<Prev in Thread] |
Current Thread |
[Next in Thread>
|
- [Xen-devel] [PATCH] Add new location of Linux direct-map to the places to look for writable mappings,
George Dunlap <=
|
|
@@ -2385,9 +2385,11 @@ int sh_remove_write_access(struct vcpu *
}
- /* 64bit Linux direct map at 0xffff810000000000; older kernels
- * had it at 0x0000010000000000UL */
+ /* 64bit Linux direct map at 0xffff880000000000; older kernels
+ * had it at 0xffff880000000000, and older kernels yet had it
+ * at 0x0000010000000000UL */
gfn = mfn_to_gfn(v->domain, gmfn);
|
|
|